-- by modelleicher
-- www.schwabenmodding.bplaced.net

disableSteeringCentering = {};

function disableSteeringCentering.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Steerable, specializations);
end;

function disableSteeringCentering:load(xmlFile)
	self.changeCenteringState = disableSteeringCentering.changeCenteringState;

	self.autoRotateBackSpeedBackup = self.autoRotateBackSpeed;
	self.centeringState = true;
end;
function disableSteeringCentering:delete()
end;
function disableSteeringCentering:mouseEvent(posX, posY, isDown, isUp, button)
end;
function disableSteeringCentering:keyEvent(unicode, sym, modifier, isDown)
end;

function disableSteeringCentering:readStream(streamId, connection)
    local centeringState = streamReadBool(streamId);
    self:changeCenteringState(centeringState, true);
end;
function disableSteeringCentering:writeStream(streamId, connection)
	streamWriteBool(streamId, self.centeringState);
end;
function disableSteeringCentering:update(dt)
	if self:getIsActiveForInput() then
		if InputBinding.hasEvent(InputBinding.TOGGLE_disableSteeringCentering) then
			self:changeCenteringState(not self.centeringState);
		end;
	end;
end;
function disableSteeringCentering:changeCenteringState(state, noEventSend)
	disableSteeringCenteringEvent.sendEvent(self, state, noEventSend);
	if state then
		self.autoRotateBackSpeed = self.autoRotateBackSpeedBackup;
	else
		self.autoRotateBackSpeed = 0;
	end;
	self.centeringState = state;
end;
function disableSteeringCentering:draw()
	if self.centeringState then
		g_currentMission:addHelpButtonText(g_i18n:getText("disableSteeringCenteringOn"), InputBinding.TOGGLE_disableSteeringCentering);
	else
		g_currentMission:addHelpButtonText(g_i18n:getText("disableSteeringCenteringOff"), InputBinding.TOGGLE_disableSteeringCentering);
	end;
end;



disableSteeringCenteringEvent = {};
disableSteeringCenteringEvent_mt = Class(disableSteeringCenteringEvent, Event);

InitEventClass(disableSteeringCenteringEvent, "disableSteeringCenteringEvent");

function disableSteeringCenteringEvent:emptyNew()
    local self = Event:new(disableSteeringCenteringEvent_mt);
    self.className = "disableSteeringCenteringEvent";
    return self;
end;

function disableSteeringCenteringEvent:new(object, state)
    local self = disableSteeringCenteringEvent:emptyNew()
    self.object = object;
	self.state = state;
    return self;
end;

function disableSteeringCenteringEvent:readStream(streamId, connection)
    local id = streamReadInt32(streamId);
	self.state = streamReadBool(streamId);
    self.object = networkGetObject(id);
    self:run(connection);
end;

function disableSteeringCenteringEvent:writeStream(streamId, connection)
    streamWriteInt32(streamId, networkGetObjectId(self.object));
	streamWriteBool(streamId, self.state);
end;

function disableSteeringCenteringEvent:run(connection)
    self.object:setIsAutoSteerBackStopped(self.state, true);
    if not connection:getIsServer() then
        g_server:broadcastEvent(disableSteeringCenteringEvent:new(self.object, self.state), nil, connection, self.object);
    end;
end;

function disableSteeringCenteringEvent.sendEvent(vehicle, state, noEventSend)
    if state ~= vehicle.centeringState then
        if noEventSend == nil or noEventSend == false then
            if g_server ~= nil then
                g_server:broadcastEvent(disableSteeringCenteringEvent:new(vehicle, state), nil, nil, vehicle);
            else
                g_client:getServerConnection():sendEvent(disableSteeringCenteringEvent:new(vehicle, state));
            end;
        end;
    end;
end;